/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Game.hh"
#include "AcceptStrategy.hh"
#include "DeclineStrategy.hh"
#include "VariableStrategy.hh"
#include "StrategyFactory.hh"

#include <iostream>

int main( int argc, char* argv[] )
{
    // Wir melden alle Strategien bei der Factory an.
    StrategyFactory& factory = StrategyFactory::getInstance();
    factory.registerStrategy( "accept",   new AcceptStrategy(0)   );
    factory.registerStrategy( "decline",  new DeclineStrategy(0)  );
    factory.registerStrategy( "variable", new VariableStrategy(0) );

    int retValue = 0;

    if ( argc == 2 )
    {
        // Erstelle Spiel.
        Game game;
        if ( !game.start( argv[1] ) )
        {
            // Es gab ein Problem.
            retValue = 1;
        }
    }
    else
    {
        std::cout << "Strategie vergessen." << std::endl;
        retValue = 2;
    }

    return retValue;
}
